==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AFloatBaseTypeNoName.h <==
// public final class soot.jimple.parser.node.AFloatBaseTypeNoName

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9f19d84b4518fc79 soot_jimple_parser_node_AFloatBaseTypeNoName
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class cf55e2dd32eddb45 soot_jimple_parser_node_PBaseTypeNoName

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseTypeNoName

#include "soot/jimple/parser/node/PBaseTypeNoName.h"

#ifndef _JC_soot_jimple_parser_node_AFloatBaseTypeNoName_H_
#define _JC_soot_jimple_parser_node_AFloatBaseTypeNoName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TFloat$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$sub_refs	_jc_soot_jimple_parser_node_AFloatBaseTypeNoName$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$sub_nonrefs	_jc_soot_jimple_parser_node_AFloatBaseTypeNoName$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$refs	_jc_soot_jimple_parser_node_AFloatBaseTypeNoName$refs;
typedef struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$nonrefs	_jc_soot_jimple_parser_node_AFloatBaseTypeNoName$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object	_jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object;

typedef const struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$vmethods	_jc_soot_jimple_parser_node_AFloatBaseTypeNoName$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$vtable	_jc_soot_jimple_parser_node_AFloatBaseTypeNoName$vtable;
typedef const struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$vtype	_jc_soot_jimple_parser_node_AFloatBaseTypeNoName$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object *);
extern void _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$method$_init$e1e143cccc9a37c8(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TFloat$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AFloatBaseTypeNoName$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object *);
extern struct _jc_soot_jimple_parser_node_TFloat$object *_jc_soot_jimple_parser_node_AFloatBaseTypeNoName$method$getFloat$d211374daf9e7e23(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object *);
extern void _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$method$setFloat$0886c6c085d53d50(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TFloat$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AFloatBaseTypeNoName$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$method_info$getFloat$d211374daf9e7e23;
extern _jc_method _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$method_info$setFloat$0886c6c085d53d50;
extern _jc_method _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object *);
	struct _jc_soot_jimple_parser_node_TFloat$object	*(*getFloat$d211374daf9e7e23)(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setFloat$0886c6c085d53d50)(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TFloat$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseTypeNoName$vmethods	soot_jimple_parser_node_PBaseTypeNoName;
	_jc_soot_jimple_parser_node_AFloatBaseTypeNoName$vmethods	soot_jimple_parser_node_AFloatBaseTypeNoName;
};

// Vtype
struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AFloatBaseTypeNoName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$sub_refs {
	struct _jc_soot_jimple_parser_node_TFloat$object	*__5ffloat__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$refs {
    _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$sub_refs	soot_jimple_parser_node_AFloatBaseTypeNoName;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_refs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_AFloatBaseTypeNoName;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object {
	_jc_soot_jimple_parser_node_AFloatBaseTypeNoName$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AFloatBaseTypeNoName$vtype	*vtype;
	_jc_soot_jimple_parser_node_AFloatBaseTypeNoName$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$vtype _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AFloatBaseTypeNoName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$class_object;

#endif	/* _JC_soot_jimple_parser_node_AFloatBaseTypeNoName_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AFloatBaseTypeNoName.h <==
// public final class soot.jimple.parser.node.AFloatBaseTypeNoName

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9f19d84b4518fc79 soot_jimple_parser_node_AFloatBaseTypeNoName
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class cf55e2dd32eddb45 soot_jimple_parser_node_PBaseTypeNoName

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseTypeNoName

#include "soot/jimple/parser/node/PBaseTypeNoName.h"

#ifndef _JC_soot_jimple_parser_node_AFloatBaseTypeNoName_H_
#define _JC_soot_jimple_parser_node_AFloatBaseTypeNoName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TFloat$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$sub_refs	_jc_soot_jimple_parser_node_AFloatBaseTypeNoName$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$sub_nonrefs	_jc_soot_jimple_parser_node_AFloatBaseTypeNoName$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$refs	_jc_soot_jimple_parser_node_AFloatBaseTypeNoName$refs;
typedef struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$nonrefs	_jc_soot_jimple_parser_node_AFloatBaseTypeNoName$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object	_jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object;

typedef const struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$vmethods	_jc_soot_jimple_parser_node_AFloatBaseTypeNoName$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$vtable	_jc_soot_jimple_parser_node_AFloatBaseTypeNoName$vtable;
typedef const struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$vtype	_jc_soot_jimple_parser_node_AFloatBaseTypeNoName$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$method$_init$e1e143cccc9a37c8(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TFloat$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AFloatBaseTypeNoName$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TFloat$object *_jc_soot_jimple_parser_node_AFloatBaseTypeNoName$method$getFloat$d211374daf9e7e23(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$method$setFloat$0886c6c085d53d50(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TFloat$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AFloatBaseTypeNoName$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$method_info$getFloat$d211374daf9e7e23;
extern _jc_method _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$method_info$setFloat$0886c6c085d53d50;
extern _jc_method _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TFloat$object	*(*getFloat$d211374daf9e7e23)(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setFloat$0886c6c085d53d50)(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TFloat$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseTypeNoName$vmethods	soot_jimple_parser_node_PBaseTypeNoName;
	_jc_soot_jimple_parser_node_AFloatBaseTypeNoName$vmethods	soot_jimple_parser_node_AFloatBaseTypeNoName;
};

// Vtype
struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AFloatBaseTypeNoName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$sub_refs {
	struct _jc_soot_jimple_parser_node_TFloat$object	*__5ffloat__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$refs {
    _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$sub_refs	soot_jimple_parser_node_AFloatBaseTypeNoName;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_refs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_AFloatBaseTypeNoName;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$object {
	_jc_soot_jimple_parser_node_AFloatBaseTypeNoName$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AFloatBaseTypeNoName$vtype	*vtype;
	_jc_soot_jimple_parser_node_AFloatBaseTypeNoName$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$vtype _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AFloatBaseTypeNoName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AFloatBaseTypeNoName$class_object;

#endif	/* _JC_soot_jimple_parser_node_AFloatBaseTypeNoName_H_ */
